@@ -143,11 +143,10 @@ impl JobApi {
         let mut request_builder = self.client.get(req_url.as_str());
 
         if let Some(location) = location {
-            request_builder = request_builder.query(&["location", location]);
+            request_builder = request_builder.query(&[("location", location)]);
         }
 
         let access_token = self.sa_auth.access_token().await?;
-
         let request = request_builder.bearer_auth(access_token).build()?;
 
         let resp = self.client.execute(request).await?;
@@ -178,7 +177,7 @@ impl JobApi {
         let mut request_builder = self.client.post(req_url.as_str());
 
         if let Some(location) = location {
-            request_builder = request_builder.query(&["location", location]);
+            request_builder = request_builder.query(&[("location", location)]);
         }
 
         let access_token = self.sa_auth.access_token().await?;
