@@ -2,7 +2,7 @@ use crate::model::bqml_iteration_result::BqmlIterationResult;
 use crate::model::bqml_training_run_training_options::BqmlTrainingRunTrainingOptions;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct BqmlTrainingRun {
     /// [Output-only, Beta] List of each iteration results.
