@@ -4,7 +4,7 @@ use crate::model::job_statistics::JobStatistics;
 use crate::model::job_status::JobStatus;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Job {
     #[serde(skip_serializing_if = "Option::is_none")]
